@@ -316,13 +316,13 @@ sub always {
             }
         }
 
-        $self->tag('wrong-vcs-location-for-dpmt')
+        $self->tag('old-dpmt-vcs')
           if $maintainer =~ m{python-modules-team\@lists\.alioth\.debian\.org}
-          and $uri !~ m{salsa.debian.org/python-team/modules/.+};
+          and $uri !~ m{salsa.debian.org/python-team/packages/.+};
 
-        $self->tag('wrong-vcs-location-for-papt')
+        $self->tag('old-papt-vcs')
           if $maintainer =~ m{python-apps-team\@lists\.alioth\.debian\.org}
-          and $uri !~ m{salsa.debian.org/python-team/applications/.+};
+          and $uri !~ m{salsa.debian.org/python-team/packages/.+};
     }
 
     $self->tag('vcs-fields-use-more-than-one-vcs',
